import ServerSideRender from '@wordpress/server-side-render';
import { InspectorControls } from '@wordpress/block-editor';
import { Disabled, FormTokenField, PanelBody, ToggleControl, RangeControl, TextControl } from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import { useBlockProps, ColorPaletteControl } from '@wordpress/block-editor';
import './editor.scss';

export default function Edit( props ) {
	const {
		attributes,
		setAttributes,
	} = props;

	const {
		blockTitle,
		postsToShow,
		selectedColumnists,
		isCarousel,
		bgColor
	} = attributes;

	const { useSelect } = wp.data;

	const { columnists } = useSelect( ( select ) => {
		const { getUsers } = select( 'core' )

		return {
			columnists: getUsers({ roles: 'colunista', per_page: 100 })
		}
	} )

	let columnistsNames = []

	if ( columnists ) {
		columnistsNames = columnists.map( column => column.name )
	}

	return (
		<>
			<InspectorControls>
				<PanelBody
					title={ __( 'Configurações', 'amazonia' ) }
				>
					<ToggleControl
						label={ __( 'Usar carousel?', 'amazonia' ) }
						checked={ isCarousel }
						onChange={ ( value ) => setAttributes( { isCarousel: value } ) }
					/>
					<TextControl
						label={ __( 'Título do bloco', 'amazonia' ) }
						value={ blockTitle }
						onChange={ ( value ) => setAttributes( { blockTitle: value } ) }
					/>
					<ColorPaletteControl
						label={ __( 'Cor de fundo', 'amazonia' ) }
						value={ bgColor }
						onChange={ ( value ) => setAttributes( { bgColor: value } ) }
					/>
					<RangeControl
						label={ __( 'Quantidade de colunistas', 'amazonia' ) }
						value={ postsToShow }
						onChange={ ( value ) =>
							setAttributes( { postsToShow: value } )
						}
						min="1"
						max="100"
					/>
					<FormTokenField
						label={ __( 'Selecione os colunistas', 'amazonia' ) }
						value={ selectedColumnists }
						suggestions={ columnistsNames }
						onChange={ ( value ) => setAttributes( { selectedColumnists: value } ) }
					/>
				</PanelBody>
			</InspectorControls>
			<div { ...useBlockProps() }>
				<Disabled>
					<ServerSideRender
						block="hacklab-blocks/columnists"
						attributes={ attributes }
					/>
				</Disabled>
			</div>
		</>
	);
}


