import ServerSideRender from '@wordpress/server-side-render';
import { InspectorControls } from '@wordpress/block-editor';
import { Disabled, FormTokenField, PanelBody, RangeControl } from '@wordpress/components';
import { __ } from '@wordpress/i18n';
import { useBlockProps } from '@wordpress/block-editor';
import './editor.scss';

export default function Edit( props ) {
	const {
		attributes,
		setAttributes,
	} = props;

	const {
		postsToShow,
		selectedEducators,
	} = attributes;

	const { useSelect } = wp.data

	const { educators } = useSelect( ( select ) => {
		const { getEntityRecords } = select( 'core' )

		// Query parameters.
        const query = {
			per_page: 99,
			orderby:  'title',
			order:    'asc'
		}

		return {
			educators: getEntityRecords( 'postType', 'educadores', query )
		}
	} )

	let educatorsNames = []

	if ( educators ) {
		educatorsNames = educators.map( educator => educator.title.rendered )
	}

	return (
		<>
			<InspectorControls>
				<PanelBody
					title={ __( 'Configurações', 'hacklab-blocks' ) }
				>
					<RangeControl
						label={ __( 'Quantidade de colunistas', 'hacklab-blocks' ) }
						value={ postsToShow }
						onChange={ ( value ) =>
							setAttributes( { postsToShow: value } )
						}
						min="1"
						max="100"
					/>
					<FormTokenField
						label={ __( 'Selecione os educadores', 'hacklab-blocks' ) }
						value={ selectedEducators }
						suggestions={ educatorsNames }
						onChange={ ( value ) => setAttributes( { selectedEducators: value } ) }
					/>
				</PanelBody>
			</InspectorControls>
			<div { ...useBlockProps() }>
				<Disabled>
					<ServerSideRender
						block="hacklab-blocks/educators"
						attributes={ attributes }
					/>
				</Disabled>
			</div>
		</>
	);
}
