 /**
  * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
  * All files containing `style` keyword are bundled together. The code used
  * gets applied both to the front of your site and to the editor. All other files
  * get applied to the editor only.
  *
  * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
  */
  import './editor.scss';

/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */

import { TextControl, Panel, PanelBody, __experimentalNumberControl as NumberControl } from '@wordpress/components';
import { __ } from "@wordpress/i18n";
import ServerSideRender from '@wordpress/server-side-render';


import React, {useCallback , useSelect, useState, useEffect } from 'react';
/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { InspectorControls } from '@wordpress/block-editor';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @param {Object}   props               Properties passed to the function.
 * @param {Object}   props.attributes    Available block attributes.
 * @param {Function} props.setAttributes Function that updates individual attributes.
 *
 * @return {WPElement} Element to render.
 */


export default function Edit( props ) {

    console.log( props );
    const {
        attributes,
        setAttributes,
    } = props;
    //console.log( wp.data.select( 'core/block-editor' ).getSettings() );
    //console.log( data.select( 'core/block-editor' ).getSettings() );
    
    const {
        postType,
        taxonomy,
        blockId
    } = attributes
    setAttributes( { blockId: props.clientId } );
  
    return (
        <>
			<InspectorControls key="setting">
				<Panel>
                    <PanelBody title={__('Configurações do bloco')}>
                        <TextControl
							label={ __('Digite a Slug da taxonomy')}
							value={ taxonomy }
							onChange={ ( taxonomy ) => {
								setAttributes( { taxonomy } )
							} }
						/>
                        <TextControl
							label={ __('Digite a Slug do Post type a ser filtrado')}
							value={ postType }
							onChange={ ( postType ) => {
								setAttributes( { postType } )
							} }
						/>
                    </PanelBody>
				</Panel>
            </InspectorControls>

            <ServerSideRender
                block="hacklab-blocks/filter-by-taxonomy"
                attributes={ attributes }        
            />
        </>
    );
}