import { useCallback, useEffect, useState } from 'react'

function getItem (key, defaultValue = null) {
    try {
        const storedValue = window.localStorage.getItem(key)
        const jsonValue = JSON.parse(storedValue ?? defaultValue)
        return jsonValue ?? defaultValue
    } catch (err) {
        return defaultValue
    }
}

function setItem (key, value) {
    if (value === undefined) {
        window.localStorage.removeItem(key)
    } else {
        const jsonValue = JSON.stringify(value)
        window.localStorage.setItem(key, jsonValue)
    }
}

export function useStorage (key, defaultValue = null) {
    const [value, setValue] = useState(defaultValue)

    const updateStorage = useCallback((val) => {
        setItem(key, val)
        setValue(val)
    }, [key, setValue])

    useEffect(() => {
        setValue(getItem(key, defaultValue))

        function onStorageUpdate (event) {
            if (event.key === key) {
                setValue(getItem(key, defaultValue))
            }
        }

        window.addEventListener('storage', onStorageUpdate)
        return () => window.removeEventListener('storage', onStorageUpdate)
    }, [key])

    return [value, updateStorage]
}
