/**
 * WordPress components that create the necessary UI elements for the block
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-components/
 */

 import { RichText, MediaUpload } from "@wordpress/block-editor";
 import { __ } from "@wordpress/i18n";
 import {
	 Card,
	 CardBody,
	 CardHeader,
 } from '@wordpress/components';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @param {Object}   props               Properties passed to the function.
 * @param {Object}   props.attributes    Available block attributes.
 * @param {Function} props.setAttributes Function that updates individual attributes.
 *
 * @return {WPElement} Element to render.
 */

 function textLimit(text = '', limit) {
	if( text.length > limit ){
		let allowedText = text.substring(0, limit)
		let noAllowedText = text.substring(limit, text.lenght)
		
		text = allowedText + "<span class='highlight'>" + noAllowedText + "</span>";
	}
	
	return text;
  }

 export default function Edit( { 
	attributes: {
		title,
		tempTitle,
		content,
		tempContent,
		iconUrl,
	},
	setAttributes } ) {

	return (
		<div className="theme-card" key="container">
			<Card>
				<CardHeader>
					<RichText
						tagName="p"
						className="title"
						value={ tempTitle }
						onChange={ ( tempTitle ) => { 
								setAttributes( { 
										title: tempTitle.substring(0, 28),
										tempTitle: textLimit( tempTitle, 28 ) 
								} )
						} }
						placeholder={__('Título', 'hacklab-blocks')}
					/>
					<MediaUpload
						onSelect={(media) => { setAttributes({ iconUrl: media.url }); }}
						type="image"
						multiple={false}
						value={iconUrl}
						render={({ open }) => (
							<div className="select-images-button is-button is-default is-large" onClick={open}>
								<span class="dashicons dashicons-format-image"></span>
							</div>
						)}
					/>
				</CardHeader>
				<CardBody>
					<RichText
						tagName="p"
						className="content"
						value={ tempContent }
						onChange={ ( tempContent ) => {
									setAttributes( { 
											content: tempContent.substring(0, 156), 
											tempContent: textLimit( tempContent, 156 ) 
									} )
							} 
						}
						placeholder={__('Conteúdo', 'hacklab-blocks')}
					/>
				</CardBody>
			</Card>
		</div>
	);
}
